/***************************************************************************************
 * @file     uart.h
 * @version  V1.0
 * @date     18 January 2018
 *
 * @note
 * VORAGO Technologies 
 *
 * @note
 * Copyright (c) 2013-2016 VORAGO Technologies. 
 *
 * @par
 * BY DOWNLOADING, INSTALLING OR USING THIS SOFTWARE, YOU AGREE TO BE BOUND BY 
 * ALL THE TERMS AND CONDITIONS OF THE VORAGO TECHNOLOGIES END USER LICENSE AGREEMENT. 
 * THIS SOFTWARE IS PROVIDED "AS IS". NO WARRANTIES, WHETHER EXPRESS, IMPLIED
 * OR STATUTORY, INCLUDING, BUT NOT LIMITED TO, IMPLIED WARRANTIES OF MERCHANTABILITY 
 * AND FITNESS FOR A PARTICULAR PURPOSE APPLY TO THIS SOFTWARE. VORAGO TECHNOLOGIES 
 * SHALL NOT, IN ANY CIRCUMSTANCES, BE LIABLE FOR SPECIAL, INCIDENTAL, OR CONSEQUENTIAL 
 * DAMAGES, FOR ANY REASON WHATSOEVER.
 *
 ****************************************************************************************/
/** @file */ 
/** \addtogroup UART 
 *  @{
 */
#ifndef __UART_H
#define __UART_H

#include <stdio.h>
#include <stdbool.h>
#include <stdlib.h>
#include <string.h>

#include "board.h"

#ifndef configUART_RX_BUFFER_SIZE
#define configUART_RX_BUFFER_SIZE   32
#endif

#define BaudToUARTCLKSCALE(baudRate) (((SYSCLK / ((baudRate) * 16)) << \
                           UART_PERIPHERAL_CLKSCALE_INT_Pos) |         \
                          (((((SYSCLK % ((baudRate) * 16)) *           \
                              64 + ((baudRate) * 8)) /                 \
                             ((baudRate) * 16))) <<                    \
                           UART_PERIPHERAL_CLKSCALE_FRAC_Pos))

#define UART0SendBreak(x) VOR_UART0->TXBREAK=(x)
#define UART1SendBreak(x) VOR_UART1->TXBREAK=(x)

/* Intializes UART0 peripheral. */
extern void UART0Init(void);

/* Writes a string to UART0, and blocks until complete. */
extern void UART0TxStr(char *pcStr);

extern uint32_t UART0GetBuffer(uint8_t *data, uint32_t limit);

/* Reads a byte from the software RX Buffer. */
extern bool UART0Read(uint8_t *pui8Data);

/* TX one byte over UART0 */
extern void UART0TxByte(uint8_t b);

/* RX one byte over UART0 (with timeout) */
extern uint8_t UART0RxByte(void);

/* check if a byte is available over UART0 */
extern bool UART0IsRxByteAvailable(void);




/* Intializes UART1 peripheral. */
extern void UART1Init(void);

/* Writes a string to UART1, and blocks until complete. */
extern void UART1TxStr(char *pcStr);

/* TX one byte over UART1 */
extern void UART1TxByte(uint8_t b);

extern uint32_t UART1GetBuffer(uint8_t *data, uint32_t limit);

#endif
